import QtQuick 2.0
import QtQuick.Layouts 1.1
import QtQuick.Particles 2.0
import "."



Rectangle
{
    id: main_window
    color: "black"
    property bool initiatedHere : false


    ListModel
    {
        id: the_model
    }

    Repeater
    {
        model: the_model
        Flower
        {
            meshPath: model.meshPath
        }
    }

    // Position of flower comes from MeshDB
    MeshPosition2dBranch
    {
        id : plan_branch
        path : PoC.GetPlansPath()
        onChildAdded:
        {
            if (!hasFlower(path))
                flowers.append({ meshPath: path })
        }
        onChildDeleted:
        {
            for (var index = 0; index < flowers.count; index++)
            {
                if (flowers.get(index).meshPath == path)
                {
                    flowers.remove(index)
                    break
                }
            }
        }
    }


    ////////////////////////////////////////////////////////////////
    // "Drones"
    ListModel
    {
        id: butterflys
    }

    Repeater
    {
        model: butterflys
        Butterfly
        {
            meshPath: model.meshPath
        }
    }

    // Position of butterfly comes from MeshDB
    MeshStateBranch
    {

        id : state_branch
        path: PoC.GetDronesPath()
        onChildAdded:
        {
            if (!initiatedHere)
            {
                // Add the new child to the ListModel, this will in turn
                // make the Repeater create a buttferfly.
                if (!hasButterfly(path))
                    butterflys.append({ meshPath: path })
            }
        }
        onChildDeleted:
        {
            for (var index = 0; index < butterflys.count; index++)
            {
                if (butterflys.get(index).meshPath == path)
                {
             //       audio.play()
                    butterflys.remove(index)
                    break
                }
            }
        }
    }

    ////////////////////////////////////////////////////////////////
    // "Threats"
    ListModel
    {
        id: ladybirds
    }

    Repeater
    {
        model: ladybirds
        Ladybird
        {
            meshPath: model.meshPath
        }
    }

    // Position of ladybird comes from MeshDB
    MeshThreatBranch
    {
        id : threat_branch
        path : PoC.GetThreatsPath()
        onChildAdded:
        {
            if (!hasLadybird(path))
                ladybirds.append({ meshPath: path })
        }
        onChildDeleted:
        {
            for (var index = 0; index < ladybirds.count; index++)
            {
                if (ladybirds.get(index).meshPath == path)
                {
                    ladybirds.remove(index)
                    break
                }
            }
        }
    }

    ////////////////////////////////////////////////////////////////



    // Text string at the top
    Text
    {
        id: caption
        anchors.left : parent.left
        anchors.right : parent.right
        anchors.top : parent.top
        horizontalAlignment : Text.AlignHCenter
        color : "navy"
        font.family : "Helvetica"
        font.pointSize : 12

        // Access MeshDB database properties:
        text : MeshDB.databaseName + " '" + MeshDB.hostName + ":" + MeshDB.portNumber + "' "
    }

    Text
    {
        id: flower_count
        anchors.left : parent.left
        anchors.top : parent.top
        color : "navy"
        font.family : "Helvetica"
        font.pointSize : 14
        style: Text.Raised
        z: 1000

        text : " Flowers: " + flowers.count
    }

    Text
    {
        id: butterfly_count
        anchors.left : parent.left
        anchors.top : flower_count.bottom
        color : "navy"
        font.family : "Helvetica"
        font.pointSize : 14
        style: Text.Raised
        z: 1000

        text : " Butterflys: " + butterflys.count
    }

    Text
    {
        id: ladybird_count
        anchors.left : parent.left
        anchors.top : butterfly_count.bottom
        color : "navy"
        font.family : "Helvetica"
        font.pointSize : 14
        style: Text.Raised
        z: 1000

        // Access MeshDB database properties:
        text : " Ladybirds: " + ladybirds.count
    }

    ParticleSystem
    {
        Emitter
        {
            id: trail
            lifeSpan: 10000
            enabled: false
        }

        ImageParticle
        {
            source: "star.png"
            color: "darkred"
            z: 0
            entryEffect: ImageParticle.Scale
        }
    } // ParticleSystem


    function emitTrailParticle( x, y)
    {
        trail.burst(1, x, y)
    }



}


